import { ReactElement } from "react";
import { Tooltip, TooltipContent, TooltipTrigger } from "@/app/components/ui/tooltip";
import Image from "next/image";
import config from "@root/config.json";
import Link from "next/link";
import { Card } from "@/app/components/card";

/**
 * The players to try out.
 */
const tryMePlayers: string[] = ["Notch", "jeb_", "Dinnerbone", "Grumm", "deadmau5"];

export function TryAPlayer(): ReactElement {
  return (
    <Card>
      <div className="flex flex-col items-center justify-center text-center">
        <div>
          <h2 className="text-lg font-semibold">Try a Player</h2>
          <p className="text-muted-foreground">Try one of these players to see how the player view works.</p>
        </div>

        <div className="flex flex-wrap justify-center gap-2 max-w-2xl mt-4">
          {tryMePlayers.map(playerName => (
            <Tooltip key={playerName}>
              <TooltipTrigger asChild>
                <div className="flex items-center justify-center bg-background p-1.5 rounded-md gap-2">
                  <Image
                    src={`${config.apiEndpoint}/player/head/${playerName}`}
                    alt={"The player's head"}
                    width={32}
                    height={32}
                  />
                  <Link href={`/player/${playerName}`} className="hover:opacity-85 transform-gpu transition-all">
                    {playerName}
                  </Link>
                </div>
              </TooltipTrigger>
              <TooltipContent>
                <p>
                  Click to try the player <b>{playerName}</b>.
                </p>
              </TooltipContent>
            </Tooltip>
          ))}
        </div>
      </div>
    </Card>
  );
}
